==> jc-1.4.0.tar.gz: java/security/Permissions__24PermissionsHash.h <==
// final class java.security.Permissions$PermissionsHash

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class c66c17eff6c1d1e6 java_security_PermissionCollection
// @dep_class 31e38aec8bfdc04d java_security_Permissions__24PermissionsHash

// header file dependencies
// @dep_header java_security_PermissionCollection

#include "java/security/PermissionCollection.h"

#ifndef _JC_java_security_Permissions__24PermissionsHash_H_
#define _JC_java_security_Permissions__24PermissionsHash_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_security_Permission$object;
struct _jc_java_security_Permissions__241$object;
struct _jc_java_util_Enumeration$object;
struct _jc_java_util_Hashtable$object;

// Typedefs
typedef struct _jc_java_security_Permissions__24PermissionsHash$sub_refs	_jc_java_security_Permissions__24PermissionsHash$sub_refs;
typedef struct _jc_java_security_Permissions__24PermissionsHash$sub_nonrefs	_jc_java_security_Permissions__24PermissionsHash$sub_nonrefs;
typedef struct _jc_java_security_Permissions__24PermissionsHash$refs	_jc_java_security_Permissions__24PermissionsHash$refs;
typedef struct _jc_java_security_Permissions__24PermissionsHash$nonrefs	_jc_java_security_Permissions__24PermissionsHash$nonrefs;
typedef struct _jc_java_security_Permissions__24PermissionsHash$object	_jc_java_security_Permissions__24PermissionsHash$object;

typedef struct _jc_java_security_Permissions__24PermissionsHash$fields_struct	_jc_java_security_Permissions__24PermissionsHash$fields_struct;
typedef const struct _jc_java_security_Permissions__24PermissionsHash$vmethods	_jc_java_security_Permissions__24PermissionsHash$vmethods;
typedef const struct _jc_java_security_Permissions__24PermissionsHash$vtable	_jc_java_security_Permissions__24PermissionsHash$vtable;
typedef const struct _jc_java_security_Permissions__24PermissionsHash$vtype	_jc_java_security_Permissions__24PermissionsHash$vtype;

// Class fields structure
struct _jc_java_security_Permissions__24PermissionsHash$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_security_Permissions__24PermissionsHash$fields_struct _jc_java_security_Permissions__24PermissionsHash$class_fields;

// Constructors
extern void _jc_java_security_Permissions__24PermissionsHash$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_security_Permissions__24PermissionsHash$object *);
extern void _jc_java_security_Permissions__24PermissionsHash$method$_init$3b48f1b974a962f5(_jc_env *, struct _jc_java_security_Permissions__24PermissionsHash$object *, struct _jc_java_security_Permissions__241$object *);

// Virtual methods
extern void _jc_java_security_Permissions__24PermissionsHash$method$add$a94198a5fd6a54ee(_jc_env *, struct _jc_java_security_Permissions__24PermissionsHash$object *, struct _jc_java_security_Permission$object *);
extern struct _jc_object *_jc_java_security_Permissions__24PermissionsHash$method$elements$7e4aa0c44b86c479(_jc_env *, struct _jc_java_security_Permissions__24PermissionsHash$object *);
extern jboolean _jc_java_security_Permissions__24PermissionsHash$method$implies$cbacf9d54b2bb917(_jc_env *, struct _jc_java_security_Permissions__24PermissionsHash$object *, struct _jc_java_security_Permission$object *);
extern void _jc_java_security_Permissions__24PermissionsHash$method$this$adc93fb6bf4cbffa(_jc_env *, struct _jc_java_security_Permissions__24PermissionsHash$object *);

// Virtual method descriptors
extern _jc_method _jc_java_security_Permissions__24PermissionsHash$method_info$add$a94198a5fd6a54ee;
extern _jc_method _jc_java_security_Permissions__24PermissionsHash$method_info$elements$7e4aa0c44b86c479;
extern _jc_method _jc_java_security_Permissions__24PermissionsHash$method_info$implies$cbacf9d54b2bb917;
extern _jc_method _jc_java_security_Permissions__24PermissionsHash$method_info$this$adc93fb6bf4cbffa;

// Virtual methods structure
struct _jc_java_security_Permissions__24PermissionsHash$vmethods {
	void	(*add$a94198a5fd6a54ee)(_jc_env *, struct _jc_java_security_Permissions__24PermissionsHash$object *, struct _jc_java_security_Permission$object *);
	struct _jc_object	*(*elements$7e4aa0c44b86c479)(_jc_env *, struct _jc_java_security_Permissions__24PermissionsHash$object *);
	jboolean	(*implies$cbacf9d54b2bb917)(_jc_env *, struct _jc_java_security_Permissions__24PermissionsHash$object *, struct _jc_java_security_Permission$object *);
	void	(*this$adc93fb6bf4cbffa)(_jc_env *, struct _jc_java_security_Permissions__24PermissionsHash$object *);
};

// Vtable
struct _jc_java_security_Permissions__24PermissionsHash$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_security_PermissionCollection$vmethods	java_security_PermissionCollection;
	_jc_java_security_Permissions__24PermissionsHash$vmethods	java_security_Permissions__24PermissionsHash;
};

// Vtype
struct _jc_java_security_Permissions__24PermissionsHash$vtype {
	_jc_type			type;
	_jc_java_security_Permissions__24PermissionsHash$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_security_Permissions__24PermissionsHash$sub_refs {
	struct _jc_java_util_Hashtable$object	*perms;
};

// Reference instance fields (object)
struct _jc_java_security_Permissions__24PermissionsHash$refs {
    _jc_java_security_Permissions__24PermissionsHash$sub_refs	java_security_Permissions__24PermissionsHash;
    _jc_java_security_PermissionCollection$sub_refs	java_security_PermissionCollection;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_security_Permissions__24PermissionsHash$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_security_Permissions__24PermissionsHash$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_security_PermissionCollection$sub_nonrefs	java_security_PermissionCollection;
    _jc_java_security_Permissions__24PermissionsHash$sub_nonrefs	java_security_Permissions__24PermissionsHash;
};

// Object instance structure
struct _jc_java_security_Permissions__24PermissionsHash$object {
	_jc_java_security_Permissions__24PermissionsHash$refs	refs[0];
	_jc_word		lockword;
	_jc_java_security_Permissions__24PermissionsHash$vtype	*vtype;
	_jc_java_security_Permissions__24PermissionsHash$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_security_Permissions__24PermissionsHash$vtype _jc_java_security_Permissions__24PermissionsHash$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_security_Permissions__24PermissionsHash, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_security_Permissions__24PermissionsHash$class_object;

#endif	/* _JC_java_security_Permissions__24PermissionsHash_H_ */

==> jc-1.4.6.tar.gz: java/security/Permissions__24PermissionsHash.h <==
// final class java.security.Permissions$PermissionsHash

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class c66c17eff6c1d1e6 java_security_PermissionCollection
// @dep_class 31e38aec8bfdc04d java_security_Permissions__24PermissionsHash

// header file dependencies
// @dep_header java_security_PermissionCollection

#include "java/security/PermissionCollection.h"

#ifndef _JC_java_security_Permissions__24PermissionsHash_H_
#define _JC_java_security_Permissions__24PermissionsHash_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_security_Permission$object;
struct _jc_java_security_Permissions__241$object;
struct _jc_java_util_Enumeration$object;
struct _jc_java_util_Hashtable$object;

// Typedefs
typedef struct _jc_java_security_Permissions__24PermissionsHash$sub_refs	_jc_java_security_Permissions__24PermissionsHash$sub_refs;
typedef struct _jc_java_security_Permissions__24PermissionsHash$sub_nonrefs	_jc_java_security_Permissions__24PermissionsHash$sub_nonrefs;
typedef struct _jc_java_security_Permissions__24PermissionsHash$refs	_jc_java_security_Permissions__24PermissionsHash$refs;
typedef struct _jc_java_security_Permissions__24PermissionsHash$nonrefs	_jc_java_security_Permissions__24PermissionsHash$nonrefs;
typedef struct _jc_java_security_Permissions__24PermissionsHash$object	_jc_java_security_Permissions__24PermissionsHash$object;

typedef struct _jc_java_security_Permissions__24PermissionsHash$fields_struct	_jc_java_security_Permissions__24PermissionsHash$fields_struct;
typedef const struct _jc_java_security_Permissions__24PermissionsHash$vmethods	_jc_java_security_Permissions__24PermissionsHash$vmethods;
typedef const struct _jc_java_security_Permissions__24PermissionsHash$vtable	_jc_java_security_Permissions__24PermissionsHash$vtable;
typedef const struct _jc_java_security_Permissions__24PermissionsHash$vtype	_jc_java_security_Permissions__24PermissionsHash$vtype;

// Class fields structure
struct _jc_java_security_Permissions__24PermissionsHash$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_security_Permissions__24PermissionsHash$fields_struct _jc_java_security_Permissions__24PermissionsHash$class_fields;

// Constructors
extern void _jc_java_security_Permissions__24PermissionsHash$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_security_Permissions__24PermissionsHash$object *) _JC_JCNI_ATTR;
extern void _jc_java_security_Permissions__24PermissionsHash$method$_init$3b48f1b974a962f5(_jc_env *, struct _jc_java_security_Permissions__24PermissionsHash$object *, struct _jc_java_security_Permissions__241$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_java_security_Permissions__24PermissionsHash$method$add$a94198a5fd6a54ee(_jc_env *, struct _jc_java_security_Permissions__24PermissionsHash$object *, struct _jc_java_security_Permission$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_java_security_Permissions__24PermissionsHash$method$elements$7e4aa0c44b86c479(_jc_env *, struct _jc_java_security_Permissions__24PermissionsHash$object *) _JC_JCNI_ATTR;
extern jboolean _jc_java_security_Permissions__24PermissionsHash$method$implies$cbacf9d54b2bb917(_jc_env *, struct _jc_java_security_Permissions__24PermissionsHash$object *, struct _jc_java_security_Permission$object *) _JC_JCNI_ATTR;
extern void _jc_java_security_Permissions__24PermissionsHash$method$this$adc93fb6bf4cbffa(_jc_env *, struct _jc_java_security_Permissions__24PermissionsHash$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_security_Permissions__24PermissionsHash$method_info$add$a94198a5fd6a54ee;
extern _jc_method _jc_java_security_Permissions__24PermissionsHash$method_info$elements$7e4aa0c44b86c479;
extern _jc_method _jc_java_security_Permissions__24PermissionsHash$method_info$implies$cbacf9d54b2bb917;
extern _jc_method _jc_java_security_Permissions__24PermissionsHash$method_info$this$adc93fb6bf4cbffa;

// Virtual methods structure
struct _jc_java_security_Permissions__24PermissionsHash$vmethods {
	void	(*add$a94198a5fd6a54ee)(_jc_env *, struct _jc_java_security_Permissions__24PermissionsHash$object *, struct _jc_java_security_Permission$object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*elements$7e4aa0c44b86c479)(_jc_env *, struct _jc_java_security_Permissions__24PermissionsHash$object *) _JC_JCNI_ATTR;
	jboolean	(*implies$cbacf9d54b2bb917)(_jc_env *, struct _jc_java_security_Permissions__24PermissionsHash$object *, struct _jc_java_security_Permission$object *) _JC_JCNI_ATTR;
	void	(*this$adc93fb6bf4cbffa)(_jc_env *, struct _jc_java_security_Permissions__24PermissionsHash$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_security_Permissions__24PermissionsHash$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_security_PermissionCollection$vmethods	java_security_PermissionCollection;
	_jc_java_security_Permissions__24PermissionsHash$vmethods	java_security_Permissions__24PermissionsHash;
};

// Vtype
struct _jc_java_security_Permissions__24PermissionsHash$vtype {
	_jc_type			type;
	_jc_java_security_Permissions__24PermissionsHash$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_security_Permissions__24PermissionsHash$sub_refs {
	struct _jc_java_util_Hashtable$object	*perms;
};

// Reference instance fields (object)
struct _jc_java_security_Permissions__24PermissionsHash$refs {
    _jc_java_security_Permissions__24PermissionsHash$sub_refs	java_security_Permissions__24PermissionsHash;
    _jc_java_security_PermissionCollection$sub_refs	java_security_PermissionCollection;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_security_Permissions__24PermissionsHash$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_security_Permissions__24PermissionsHash$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_security_PermissionCollection$sub_nonrefs	java_security_PermissionCollection;
    _jc_java_security_Permissions__24PermissionsHash$sub_nonrefs	java_security_Permissions__24PermissionsHash;
};

// Object instance structure
struct _jc_java_security_Permissions__24PermissionsHash$object {
	_jc_java_security_Permissions__24PermissionsHash$refs	refs[0];
	_jc_word		lockword;
	_jc_java_security_Permissions__24PermissionsHash$vtype	*vtype;
	_jc_java_security_Permissions__24PermissionsHash$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_security_Permissions__24PermissionsHash$vtype _jc_java_security_Permissions__24PermissionsHash$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_security_Permissions__24PermissionsHash, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_security_Permissions__24PermissionsHash$class_object;

#endif	/* _JC_java_security_Permissions__24PermissionsHash_H_ */
